CustomerInfo class

Annotations

Constructors

CustomerInfo({required Map<String, EntitlementInfo> allEntitlements, required String firstSeen, required String requestDate})
const

Properties

allEntitlements Map<String, EntitlementInfo>
Map of all EntitlementInfo (EntitlementInfo) objects (active and inactive) keyed by entitlement identifier.
final
firstSeen String
The date this user was first seen in 3rd party (like RevenueCat).
final
hashCode int
The hash code for this object.
no setterinherited
requestDate String
Date when this info was requested.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({Map<String, EntitlementInfo>? allEntitlements, String? firstSeen, String? requestDate}) CustomerInfo
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
purchased(String entitlementID) bool
Handy method for checking whether or not user has access to an configured entitlement (through entitlementID).
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited