EntitlementInfo class

Annotations

Constructors

EntitlementInfo({required String identifier, required bool isActive, required bool willRenew, required String latestPurchaseDate, required String originalPurchaseDate, required String? expirationDate, required String? unsubscribeDetectedAt, required PeriodType periodType})
const

Properties

expirationDate String?
The expiration date for the entitlement, can be null for lifetime access.
final
hashCode int
The hash code for this object.
no setterinherited
identifier String
The entitlement identifier configured in the 3rd party dashboard (like RevenueCat).
final
isActive bool
True if the user has access to this entitlement.
final
latestPurchaseDate String
The latest purchase or renewal date for the entitlement.
final
originalPurchaseDate String
The first date this entitlement was purchased.
final
periodType PeriodType
The last period type this entitlement was in.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
unsubscribeDetectedAt String?
The date an unsubscribe was detected. Can be null if it's still subscribed or product is not a subscription.
final
willRenew bool
True if the underlying subscription is set to renew at the end of the billing period (expirationDate).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited